"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsonValidator_1 = require("../../src/utils/jsonValidator");
describe('validateJson', () => {
    it('should return true for valid JSON', () => {
        const validJson = '{"name":"John","age":30}';
        const result = (0, jsonValidator_1.validateJson)(validJson);
        expect(result).toBe(true);
    });
    it('should return true for a valid JSON array', () => {
        const validJsonArray = '[1, 2, 3, "hello", true, null]';
        const result = (0, jsonValidator_1.validateJson)(validJsonArray);
        expect(result).toBe(true);
    });
    it('should return false for invalid JSON with missing quotes around keys', () => {
        const invalidJson = '{name:"John",age:30}';
        const result = (0, jsonValidator_1.validateJson)(invalidJson);
        expect(result).toBe(false);
    });
    it('should return false for invalid JSON with a trailing comma', () => {
        const invalidJson = '{"name":"John","age":30,}';
        const result = (0, jsonValidator_1.validateJson)(invalidJson);
        expect(result).toBe(false);
    });
    it('should return false for invalid JSON with mismatched brackets', () => {
        const invalidJson = '{"name":"John","age":30}]';
        const result = (0, jsonValidator_1.validateJson)(invalidJson);
        expect(result).toBe(false);
    });
    it('should return false for an empty string', () => {
        const emptyString = '';
        const result = (0, jsonValidator_1.validateJson)(emptyString);
        expect(result).toBe(false);
    });
});
//# sourceMappingURL=jsonValidator.test.js.map